@@ -249,7 +249,7 @@
 (defcustom root-include-directory 
   (if (getenv "ROOTSYS") 
       (concat (getenv "ROOTSYS") "/include")
-    "/usr/include/root")
+    "/usr/include")
   "Where the ROOT headers reside"
   :group 'root)
 
